* Some portions of the code can only be run in Stata 13
* Each figure and table can be run individually - just search for them.

* Figure 1
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset historical_turnaround_job1, failure(historical_complete_job1)

sts test role if inlist(role,1,2), wilcoxon
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3), wilcoxon
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4), wilcoxon
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))

forval i = 1/4 {
  stci if role == `i', median 
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(role) legend(r(1) region(ls(none))) tmax(80) /// 
  title("") xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation")  ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/figure1.pdf, replace



* Figure 2a
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)

sts test role if inlist(role,1,2), wilcoxon 
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3), wilcoxon 
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4), wilcoxon 
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,4), wilcoxon 

forval i = 1/4 {
  stci if role == `i', median 
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(role) legend(r(1) region(ls(none))) tmax(80) /// 
  title("A. Baseline estimates", size(small)) xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red)) plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/figure2a.pdf, replace



* Figure 2b
use jpube_anonymized.dta, clear
* DFL weights for primary sample
keep if in_experiment
* Generate DFL weights
* 1. Group into bins based on review times (7 groups based on times)
egen byte hist_dur1 = cut(historical_turnaround_job1), at(0(30)180 1000) icodes
replace hist_dur1 = hist_dur1+1
* 2. One group for people with missing review times
mvencode hist_dur1, mv(0), if historical_turnaround_job1 == .
* 3. Create weights
gen iw_dfl = 1 if control == 1
bys hist_dur1: egen p = mean(social) if inlist(role,1,2)
replace iw_dfl = (1-p)/p if social == 1
drop p
bys hist_dur1: egen p = mean(fourweek) if inlist(role,1,3)
replace iw_dfl = (1-p)/p if fourweek == 1
drop p
bys hist_dur1: egen p = mean(cash) if inlist(role,1,4)
replace iw_dfl = (1-p)/p if cash == 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)

sts test role if inlist(role,1,2), wilcoxon strata(hist_dur1)
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3), wilcoxon strata(hist_dur1)
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4), wilcoxon strata(hist_dur1)
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,4), wilcoxon strata(hist_dur1)

stset stoptime [pw=iw_dfl], failure(complete) origin(time invtime) scale(86400000)
forval i = 1/4 {
  stsum if role == `i'
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(role) legend(r(1) region(ls(none))) tmax(80) ///
  title("B. DFL reweighted estimates" , size(small)) xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red)) plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/figure2b.pdf, replace



* Figure 3
use jpube_anonymized.dta, clear
keep if in_experiment_itt

gen byte rrole = .
replace rrole = 1 if role == 3 & main_round
replace rrole = 2 if role == 4 & main_round
replace rrole = 3 if role == 3 & nocash_round
replace rrole = 4 if role == 4 & nocash_round
la def rroles 1 "4week" 2 "Cash" 3 "4 Week 'post'" 4 "Cash 'post'", replace
la val rrole rroles

stset stoptime, failure(complete) origin(time invtime) scale(86400000) if(inlist(1,main_round,nocash_round) & agreed == 1)
foreach o in  wilcoxon {
  sts test rrole if inlist(rrole,1,2), wilcoxon 
  local cash_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
  sts test rrole if inlist(rrole,3,4), wilcoxon 
  local postcash_post4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
}

stset stoptime , failure(complete) origin(time invtime) scale(86400000) if(inlist(1,main_round,nocash_round) & agreed == 1)
forvalues i=1/4 {
  stsum if rrole==`i'
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(rrole) legend(r(1) region(ls(none))) tmax(80) ///
  xline(29, lc(black)) xline(22, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  legend(lab(1 "4 Week") lab(2 "Cash") lab(3 "4 Week (post)") lab(4 "Post-Cash") region(ls(none))) ///
  text(.97 39.5 "Cash = 4 Week: `cash_4week_p'", place(se)) text(0.89 40 "Cash After May =", place(se)) text(0.81 43 "4 Week After May: `postcash_post4week_p'", place(se)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 21 "4 Week: `median1'", place(sw) c(orange)) text(.15 21 "Cash: `median2'", place(sw) c(midgreen)) text(.1 21 "4 W After May: `median3'", place(sw) c(orange_red)) text(.05 21 "C After May: `median4'", place(sw) c(forest_green)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(orange)) plot2opt(lcolor(midgreen)) plot3opt(lcolor(orange_red)) plot4opt(lcolor(forest_green))
graph export output/figure3.pdf, replace



* Figure 4a
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)
  
sts test role if inlist(role,1,2)  & tenured == 1, wilcoxon 
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3) & tenured == 1, wilcoxon  
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4)  & tenured == 1, wilcoxon 
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,1)  & tenured == 1, wilcoxon 
  
stset stoptime , failure(complete) origin(time invtime) scale(86400000)
forval i = 1/4 {
  stsum if role == `i' & tenured == 1
  local median`i' = string(r(p50), "%3.1f")
}

sts if tenured == 1, survival by(role) legend(r(1) region(ls(none))) tmax(80) ///
  title("A. Tenured Referees Turnaround Times", size(small)) /// 
  xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/figure4a.pdf, replace



* Figure 4b
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)

sts test role if inlist(role,1,2)  & tenured == 0, wilcoxon 
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3) & tenured == 0, wilcoxon  
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4)  & tenured == 0, wilcoxon 
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,1)  & tenured == 0, wilcoxon 
  
stset stoptime , failure(complete) origin(time invtime) scale(86400000)
forval i = 1/4 {
  stsum if role == `i' & tenured == 0
  local median`i' = string(r(p50), "%3.1f")
}

sts if tenured == 0, survival by(role) legend(r(1) region(ls(none))) tmax(80) ///
  title("A. Tenured Referees Turnaround Times", size(small)) /// 
  xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/figure4b.pdf, replace



* Figure 5
use all_journals_anonymized, clear
stset stoptime, failure(complete) origin(time invtime) scale(86400000) if(agreed == 1 & other == 1 & inrange(invtime,first_treated_anyjournal,mdyhms(12,31,2011,0,0,0)) & inlist(jpuberole,1,2,3,4))

forval i = 1/4 {
  stsum if jpuberole == `i'
  local median`i' = string(r(p50), "%3.1f")
}
sts test jpuberole if inlist(jpuberole,1,2), wilcoxon
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test jpuberole if inlist(jpuberole,1,3), wilcoxon
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test jpuberole if inlist(jpuberole,3,4), wilcoxon
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test jpuberole if inlist(jpuberole,1,4), wilcoxon

sts, survival by(jpuberole) legend(r(1) region(ls(none))) tmax(80) ///
  title("") xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp(-)) xline(39, lc(gray) lp(-)) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 week = 4 week: `control_4week_p'", place(sw)) text(0.89 80 "6 week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.05 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.05 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen))
graph export output/figure5.pdf, replace



* Appendix Figure 2a
use jpube_anonymized.dta, clear
keep if in_experiment_itt == 1
* Restrict cash group to those that received invitations to review a paper by May 9
drop if nocash_round & cash
stset stoptime, failure(complete) origin(time invtime) scale(86400000)

sts test role if inlist(role,1,2), wilcoxon
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3), wilcoxon
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4), wilcoxon
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
	
stset stoptime, failure(complete) origin(time invtime) scale(86400000)
forval i = 1/4 {
  stsum if role == `i'
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(role) legend(r(1) region(ls(none))) tmax(80) /// ci cen(m) adjustfor(hist_dur_av)	title("Referee turnaround times by treatment group adjusted for historical average, by week", size(small)) /// 
  title("A. Extended sample" , size(small)) xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/appfigure2a.pdf, replace



* Appendix Figure 2b
use jpube_anonymized.dta, clear
* DFL weights ake extended sample
keep if in_experiment_itt
* Restrict cash group to those that received invitations to review a paper by May 9
drop if nocash_round & cash
* Generate DFL weights
* 1. Group into bins based on review times
forvalues i=1/3 {
    * Last three jobs' duration: 3 categories + 0 if missing, and a mising dummy
    egen byte hist_dur`i' = cut(historical_turnaround_job`i'), at(0(30)180 1000) icodes
    replace hist_dur`i' = hist_dur`i'+1
    mvencode hist_dur`i', mv(0), if historical_turnaround_job`i'==.
}
* 3. Create weights
gen iw_dfl = 1 if control == 1
bys hist_dur1: egen p = mean(social) if inlist(role,1,2)
replace iw_dfl = (1-p)/p if social==1
drop p
bys hist_dur1: egen p = mean(fourweek) if inlist(role,1,3)
replace iw_dfl = (1-p)/p if fourweek==1
drop p
bys hist_dur1: egen p = mean(cash) if inlist(role,1,4)
replace iw_dfl = (1-p)/p if cash==1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)

sts test role if inlist(role,1,2), wilcoxon strata(hist_dur1)
local control_social_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,1,3), wilcoxon strata(hist_dur1)
local control_4week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test role if inlist(role,3,4), wilcoxon strata(hist_dur1)
local 4week_cash_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
	
stset stoptime [pw=iw_dfl], failure(complete) origin(time invtime) scale(86400000)
forval i = 1/4 {
  stsum if role == `i'
  local median`i' = string(r(p50), "%3.1f")
}

sts, survival by(role) legend(r(1) region(ls(none))) tmax(80) /// ci cen(m) adjustfor(hist_dur_av)	title("Referee turnaround times by treatment group adjusted for historical average, by week", size(small)) /// 
  title("B. DFL reweighted estimates, extended sample", size(small)) xline(46, lc(black)) xline(29, lc(black)) xline(22, lc(gray) lp("-")) xline(39, lc(gray) lp("-")) ///
  ytitle("Percentage of Reports Still Pending") xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ///
  text(.97 80 "6 Week = 4 Week: `control_4week_p'", place(sw)) text(0.89 80 "6 Week = Social: `control_social_p'", place(sw))  text(0.81 80 "4 Week = Cash: `4week_cash_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 17 "6 Week: `median1'", place(sw) c(red)) text(.15 17 "Social: `median2'", place(sw) c(midblue)) text(.1 17 "4 Week: `median3'", place(sw) c(orange)) text(.05 17 "Cash: `median4'", place(sw) c(midgreen)) ///
  text(0.03 22 "4 week reminder", place(ne) size(vsmall)) text(0 29 "4 week deadline", place(ne) size(vsmall)) text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall)) ///
  plot1opt(lcolor(red))  plot2opt(lcolor(midblue)) plot3opt(lcolor(orange)) plot4opt(lcolor(midgreen)) ///
  legend(lab(1 "6 Week") lab(2 "Social") lab(3 "4 Week") lab(4 "Cash") region(ls(none)))
graph export output/appfigure2b.pdf, replace



* Appendix Figure 3
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset stoptime , failure(complete) origin(time invtime) scale(86400000)
gen byte contrast = tenure == 1 & role == 2

sts test role if tenure == 0 & role < 3, wilcoxon  
sts test role if tenure == 1 & role < 3, wilcoxon  
sts test tenure if role == 1, wilcoxon 
local unten_ten_6week_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))
sts test tenure if role == 2, wilcoxon 
sts test contrast if (role == 2 & tenure == 1) | (role == 1 & tenure == 0), wilcoxon 
local unten6week_tensocial_p = cond(chi2tail(r(df),r(chi2))<0.001,"p < 0.001"," p = " + string(chi2tail(r(df),r(chi2)), "%4.3f"))

forvalues i=1/2 {
forvalues j=0/1 {
  stsum if role == `i' &  tenure == `j'
  local median`i'`j' = string(r(p50), "%3.1f")
}
}

sts if (role < 2) | (tenure ==1 & role < 3), survival by(role tenure) tmax(80) ///
  title("") plot1(lc(red) lp("-")) plot2(lc(red)) plot3(lc(blue)) ///
  xline(46, lc(black)) xline(39, lc(gray) lp("-")) legend(lab(1 "Untenured 6 Week") lab(2 "Tenured 6 Week") lab(3 "Tenured Social") region(ls(none))) ///
  xtitle("Days since invitation") ylabel(0 "0%" 0.25 "25%" 0.5 "50%" 0.75 "75%" 1 "100%") yscale(range(0 1)) ytitle("Percentage of Reports Still Pending") ///
  text(.97 46 "Untenured 6 Week = ", place(se)) text(0.89 80 "Tenured Social: `unten6week_tensocial_p'", place(sw)) text(.81 46 "Untenured 6 Week = ", place(se)) text(0.73 80 "Tenured 6 Week: `unten_ten_6week_p'", place(sw)) ///
  text(.25 0 "Median Survival Times", place(se)) text(.20 30 "Untenured 6 Week: `median10'", place(sw) c(red)) text(.15 30 "Tenured 6 Week: `median11'", place(sw) c(red)) text(.1 30 "Tenured Social: `median21'", place(sw) c(midblue)) ///
  text(0.03 39 "6 week reminder", place(ne) size(vsmall)) text(0 46 "6 week deadline", place(ne) size(vsmall))
graph export output/appfigure3.pdf, replace



* Table 2
use jpube_anonymized.dta, clear
reg agreed i.role if main_round == 1, cluster(reviewerpeopleid)
margins role
test 3.role == 4.role
tab role if main_round == 1



* Table 3
use jpube_anonymized.dta, clear
keep if in_experiment == 1
reg ref_ed_agree i.role if complete == 1, cluster(reviewerpeopleid)
margins role
test 3.role == 4.role
tab role if e(sample)
qreg reviewwordcount_author i.role if complete == 1
margins role
test 3.role == 4.role
tab role if e(sample)



* Table 4
use all_journals_anonymized, clear
stset stoptime, failure(complete) origin(time invtime) scale(86400000) if(agreed == 1 & other == 1 & inrange(invtime,first_treated_anyjournal,mdyhms(12,31,2011,0,0,0)) & inlist(jpuberole,1,2,3,4))
* Panel A
reg agreed i.jpuberole  if other == 1 & inrange(invtime,first_treated_anyjournal,mdyhms(12,31,2011,0,0,0)), cluster(jpube_peopleid)
margins jpuberole
test 3.jpuberole == 4.jpuberole
tab jpuberole if e(sample)
* Panel B
forval i = 1/4 {
  stci if jpuberole == `i'
}
tab jpuberole if _st
sts test jpuberole if inlist(jpuberole,1,2), wilcoxon
sts test jpuberole if inlist(jpuberole,1,3), wilcoxon
sts test jpuberole if inlist(jpuberole,3,4), wilcoxon



* Appendix Table 1
use jpube_anonymized.dta, clear
su agreed if main_round == 1
su censored if agreed == 1 & main_round == 1
su turnaround if agreed == 1  & main_round == 1 & complete, det
su nohist if agreed == 1 & main_round == 1
keep if agreed == 1 & main_round == 1
collapse (max) jobcount_under_treatment tenured academic us female, by(reviewerpeopleid)
tab jobcount_under_treatment
su tenured academic us female



* Appendix Table 2
use jpube_anonymized.dta, clear
egen historical_turnaround_3jobs = rowmean(historical_turnaround_job?)
* Panel A
foreach v of varlist nohist historical_agreed tenured academic us female {
  reg `v' ibn.role if main_round == 1, cluster(reviewerpeopleid) nocons
  test 1.role = 2.role = 3.role = 4.role
}
tab role if main_round == 1
qui qreg historical_turnaround_3jobs i.role if main_round == 1  // requires stata 13
margins role  // requires stata 13
test 1.role = 2.role = 3.role = 4.role
*Panel B
foreach v of varlist nohist historical_agreed tenured academic us female {
  reg `v' ibn.role if main_round == 1 & agreed == 1, cluster(reviewerpeopleid) nocons
  test 1.role = 2.role = 3.role = 4.role
}
tab role if main_round == 1 & agreed == 1
qreg historical_turnaround_3jobs i.role if main_round == 1 & agreed ==1  // requires stata 13
margins role  // requires stata 13
test 1.role = 2.role = 3.role = 4.role



* Appendix Table 3
use jpube_anonymized.dta, clear
keep if in_experiment == 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000)
* Panel A
forval i = 1/4 {
  stci if role == `i'
}
* Panel B
forval i = 1/4 {
  stci if role == `i' & tenured == 1
}
* Panel C
forval i = 1/4 {
  stci if role == `i' & tenured == 0
}



* Appendix Table 4
use jpube_anonymized.dta, clear
* DFL weights ake extended sample
keep if in_experiment_itt
* Generate DFL weights
* 1. Group into bins based on review times
forvalues i=1/3 {
  egen byte hist_dur`i' = cut(historical_turnaround_job`i'), at(0(60)180 1000) icodes
  replace hist_dur`i' = hist_dur`i'+1
  * 2. One group for people with missing review times
  mvencode hist_dur`i', mv(0), if historical_turnaround_job`i' == .
}
* 3. Create weights
gen iw_dfl = 1 if control == 1
bys hist_dur1: egen p = mean(social) if inlist(role,1,2)
replace iw_dfl = (1-p)/p if social == 1
drop p
bys hist_dur1: egen p = mean(fourweek) if inlist(role,1,3)
replace iw_dfl = (1-p)/p if fourweek == 1
drop p
bys hist_dur1: egen p = mean(cash) if inlist(role,1,4)
replace iw_dfl = (1-p)/p if cash == 1
* Censor durations at 140 days
local censor 140
replace complete = 0 if turnaround > `censor'
replace stoptime = invtime + `censor'*86400000 if turnaround > `censor'
* Recode covariates to 0 if they're missing and construct indicators for missing values
local zero_if_miss_controls "tenure historical_agreed academic us wordcount tabcount eqcount"
local dummy_for_missing_controls ""
local other_controls "i.hist_dur?"
foreach v of varlist `zero_if_miss_controls' {
  misstable summarize `v'
  if r(N_eq_dot) > 0 {
    gen byte miss_`v' = mi(`v')
    local dummy_for_missing_controls "`dummy_for_missing_controls' miss_`v'" 
  }
}
mvencode `zero_if_miss_controls', mv(0) override
* Indicators for when the cash treatment was ended
gen byte post_cash = cash & nocash_round
replace cash = 0 if nocash_round
* Column 1
stset stoptime, failure(complete) origin(time invtime) scale(86400000) id(id)
local controls "`zero_if_miss_controls' `other_controls' `dummy_for_missing_controls'"
stcox deadline_4week cash social post_cash, cluster(reviewerpeopleid) nohr efron strata(invmonth)
* Column 2
stcox deadline_4week cash social post_cash `controls', cluster(reviewerpeopleid) nohr efron strata(invmonth)
* Column 3
stcox deadline_4week cash social `controls' if main_round==1, cluster(reviewerpeopleid) nohr strata(invmonth) efron
* Column 4
keep _* deadline_4week cash social post_cash `zero_if_miss_controls' `dummy_for_missing_controls' hist_dur?  reviewerpeopleid invmonth stoptime duetime id
stsplit, at(failures)
gen byte neardue = inrange(hours(stoptime-duetime)/24,-7,0)
gen byte postdue = inrange(hours(stoptime-duetime)/24,0,7)
stcox deadline_4week cash social post_cash *due 1.cash#1.neardue 1.cash#1.postdue 1.post_cash#1.neardue 1.post_cash#1.postdue  `controls', cluster(reviewerpeopleid) nohr efron strata(invmonth)
